cgexplore.terms.TargetTorsionRange
==================================

.. currentmodule:: cgexplore.terms

.. autoclass:: TargetTorsionRange
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~TargetTorsionRange.yield_torsions
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~TargetTorsionRange.search_string
      ~TargetTorsionRange.search_estring
      ~TargetTorsionRange.measured_atom_ids
      ~TargetTorsionRange.phi0s
      ~TargetTorsionRange.torsion_ks
      ~TargetTorsionRange.torsion_ns
   
   